@@ -1,9 +1,8 @@
 use crate::prelude::*;
 use nu_engine::WholeStreamCommand;
 use nu_errors::ShellError;
-use nu_protocol::{dataframe::NuSeries, Signature, SyntaxShape};
+use nu_protocol::{dataframe::NuDataFrame, Signature, SyntaxShape};
 use nu_source::Tagged;
-use polars::prelude::IntoSeries;
 
 pub struct DataFrame;
 
@@ -27,7 +26,7 @@ impl WholeStreamCommand for DataFrame {
     fn examples(&self) -> Vec<Example> {
         vec![Example {
             description: "Shifts the values by a given period",
-            example: "[1 2 2 3 3] | dataframe to-series | dataframe shift 2",
+            example: "[1 2 2 3 3] | dataframe to-df | dataframe shift 2",
             result: None,
         }]
     }
@@ -37,12 +36,10 @@ fn command(mut args: CommandArgs) -> Result<OutputStream, ShellError> {
     let tag = args.call_info.name_tag.clone();
     let period: Tagged<i64> = args.req(0)?;
 
-    let series = NuSeries::try_from_stream(&mut args.input, &tag.span)?;
+    let (df, df_tag) = NuDataFrame::try_from_stream(&mut args.input, &tag.span)?;
 
-    let res = series.as_ref().shift(period.item);
+    let res = df.as_series(&df_tag.span)?.shift(period.item);
 
-    Ok(OutputStream::one(NuSeries::series_to_value(
-        res.into_series(),
-        tag,
-    )))
+    let df = NuDataFrame::try_from_series(vec![res], &tag.span)?;
+    Ok(OutputStream::one(df.into_value(df_tag)))
 }
